"use strict";
// Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license.
// See LICENSE in the project root for license information.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPseudolocalizer = void 0;
const vm_1 = __importDefault(require("vm"));
const node_core_library_1 = require("@rushstack/node-core-library");
const pseudolocalePath = require.resolve('pseudolocale/pseudolocale.min.js');
/**
 * Get a function that pseudolocalizes a string.
 *
 * @public
 */
function getPseudolocalizer(options) {
    const pseudolocaleCode = node_core_library_1.FileSystem.readFile(pseudolocalePath);
    const context = {
        pseudolocale: undefined
    };
    // Load pseudolocale in an isolated context because the configuration for is stored on a singleton
    vm_1.default.runInNewContext(pseudolocaleCode, context);
    const { pseudolocale } = context;
    if (!pseudolocale) {
        throw new Error(`Failed to load pseudolocale module`);
    }
    Object.assign(pseudolocale.option, options);
    // `pseudolocale.str` captures `pseudolocale` in its closure and refers to `pseudolocale.option`.
    return pseudolocale.str;
}
exports.getPseudolocalizer = getPseudolocalizer;
//# sourceMappingURL=Pseudolocalization.js.map